@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -23,6 +23,12 @@
 ##
 ## Accuracy: The result is a tight enclosure.
 ##
+## @example
+## @group
+## cancelplus (infsup (2, 3), infsup (1, 1.5))
+##   @result{} [3.5, 4]
+## @end group
+## @end example
 ## @seealso{@@infsup/cancelminus}
 ## @end deftypefn
 
@@ -39,4 +45,7 @@ endif
 
 result = cancelminus (x, -y);
 
-endfunction
\ No newline at end of file
+endfunction
+
+%!test "from the documentation string";
+%! assert (cancelplus (infsup (2, 3), infsup (1, 1.5)) == infsup (3.5, 4));
