@@ -90,19 +90,24 @@ endif
 
 ## Check parameters
 if (not (isa (x0, "infsup")))
-    error ("fzero: Parameter X0 is no interval")
+    error ("interval:InvalidOperand", "fzero: Parameter X0 is no interval")
 elseif (not (isscalar (x0)))
-    error ("fzero: Parameter X0 must be a scalar / F must be univariate")
+    error ("interval:InvalidOperand", ...
+           "fzero: Parameter X0 must be a scalar / F must be univariate")
 elseif (isempty (x0))
-    error ("fzero: Initial interval is empty, nothing to do")
+    error ("interval:InvalidOperand", ...
+           "fzero: Initial interval is empty, nothing to do")
 elseif (not (is_function_handle (f)) && not (ischar (f)))
-    error ("fzero: Parameter F is no function handle")
+    error ("interval:InvalidOperand", ...
+           "fzero: Parameter F is no function handle")
 elseif (not (isempty (df)) && ...
         not (is_function_handle (df)) && ...
         not (ischar (df)))
-    error ("fzero: Parameter DF is not function handle")
+    error ("interval:InvalidOperand", ...
+           "fzero: Parameter DF is not function handle")
 elseif (not (isreal (maxsteps)) || maxsteps < 1)
-    error ("fzero: Parameter MAXSTEPS must be a positive real number")
+    error ("interval:InvalidOperand", ...
+           "fzero: Parameter MAXSTEPS must be a positive real number")
 endif
 
 ## Does not work on decorated intervals, strip decoration part
@@ -128,7 +133,7 @@ l = u = zeros (0, 1);
 ## Try the newton step, if derivative is known
 if (not (isempty (df)))
     m = infsup (mid (x0));
-    [a, b] = mulrevtopair (feval (df, x0), feval (f, m));
+    [a, b] = mulrev (feval (df, x0), feval (f, m));
     if (isempty (a) && isempty (b))
         ## Function evaluated outside of its domain
         a = x0;
@@ -211,3 +216,13 @@ for x1 = {a, b}
 endfor
 
 endfunction
+
+%!test "from the documentation string";
+%! f = @(x) cos (x);
+%! df = @(x) -sin (x);
+%! zeros = fzero (f, infsup ("[-10, 10]"), df);
+%! assert (all (subset (pi * (-2.5:1:2.5)', zeros)));
+%! assert (max (rad (zeros)) < 8 * eps);
+%! zeros = fzero ("sqr", infsup ("[Entire]"));
+%! assert (all (subset (0, zeros)));
+%! assert (max (rad (zeros)) < eps);
