@@ -97,6 +97,12 @@ if (nargin == 0)
 endif
 
 if (nargin == 1)
+    if (isa (l, "infsup"))
+        ## Nothing to be done
+        x = l;
+        isexact = true ();
+        return
+    endif
     if (ischar (l))
         l = cellstr (l);
     endif
@@ -178,8 +184,16 @@ if (ischar (u))
 endif
 
 if (not (size_equal (l, u)))
-    error ("interval:InvalidOperand", ...
-           "infsup: size of upper and lower bounds must match")
+    if (isscalar (l))
+        ## Broadcast l
+        l = l (ones (size (u)));
+    elseif (isscalar (u))
+        ## Broadcast u
+        u = u (ones (size (l)));
+    else
+        error ("interval:InvalidOperand", ...
+               "infsup: size of upper and lower bounds must match")
+    endif
 endif
 
 ## check parameters and conversion to double precision
@@ -579,6 +593,11 @@ endfunction
 %!  assert (sup (infsup ({"0.1", 42; "e", "3.2/8"}, {"0xffp2", "42e1"; "pi", 2})), [1020, 420; pi + 2 * eps, 2]);
 %!  assert (inf (infsup ({"[2, 3]", "3/4", "[Entire]", "42?3", 1, "0xf"})), [2, 0.75, -inf, 39, 1, 15]);
 %!  assert (sup (infsup ({"[2, 3]", "3/4", "[Entire]", "42?3", 1, "0xf"})), [3, 0.75, +inf, 45, 1, 15]);
+%!test "broadcasting";
+%!  assert (inf (infsup (magic (3), 10)), magic (3));
+%!  assert (sup (infsup (magic (3), 10)), 10 * ones (3));
+%!  assert (inf (infsup (1, magic (3))), ones (3));
+%!  assert (sup (infsup (1, magic (3))), magic (3));
 %!error infsup ("[nai]");
 %!error infsup ({42, "[nai]"});
 %!error infsup (3, 2);
