@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -37,4 +37,15 @@ endif
 
 ## This check also works for empty intervals (-inf ~= +inf)
 result = (x.inf == x.sup);
-return
+
+endfunction
+
+%!assert (issingleton (infsup (0)));
+%!assert (issingleton (infsupdec (0)));
+
+%!assert (not (issingleton (entire ())));
+%!assert (not (issingleton (intervalpart (entire ()))));
+%!assert (not (issingleton (empty ())));
+%!assert (not (issingleton (intervalpart (empty ()))));
+
+%!warning assert (not (issingleton (infsupdec (2, 1))));
