@@ -17,7 +17,7 @@
 ## @documentencoding utf-8
 ## @deftypefn {Function File} {} tan (@var{X})
 ## 
-## Compute the tangent for each number in interval @var{X} in radians.
+## Compute the tangent in radians.
 ##
 ## Accuracy: The result is a tight enclosure.
 ##
@@ -48,8 +48,6 @@ l = u = zeros (size (x));
 width = mpfr_function_d ('minus', -inf, x.sup, x.inf);
 pi.sup = 0x6487ED5 * pow2 (-25) + 0x442D190 * pow2 (-55);
 certainlyfullperiod = width >= pi.sup;
-l (certainlyfullperiod) = -inf;
-u (certainlyfullperiod) = inf;
 
 possiblynotfullperiod = not (certainlyfullperiod);
 l (possiblynotfullperiod) = mpfr_function_d ('tan', -inf, x.inf (possiblynotfullperiod));
@@ -61,7 +59,6 @@ singularity = certainlyfullperiod | ...
                       sign (l) == sign (u) | ...
                       max (abs (l), abs (u)) < 1));
 
-nosingularity = not (singularity);
 l (singularity) = -inf;
 u (singularity) = inf;
 
