@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -20,6 +20,9 @@
 ## 
 ## Compute the reverse tangent function.
 ##
+## That is, an enclosure of all @code{x ∈ @var{X}} where
+## @code{tan (x) ∈ @var{C}}.
+##
 ## Accuracy: The result is a valid enclosure.
 ##
 ## @example
@@ -103,3 +106,6 @@ else
 endif
 
 endfunction
+
+%!test "from the documentation string";
+%! assert (tanrev (infsup (0), infsup (2, 4)) == infsup ("pi"));
