@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -49,4 +49,7 @@ result = mpfr_function_d ('minus', +inf, x.sup, x.inf);
 
 result (isempty (x)) = nan ();
 
-return
\ No newline at end of file
+endfunction
+
+%!test "from the documentation string";
+%! assert (wid (infsup (2.5, 3.5)), 1);
