@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,11 +18,17 @@
 ## @deftypefn {Function File} {@var{X} =} atan2rev2 (@var{A}, @var{C}, @var{X})
 ## @deftypefnx {Function File} {@var{X} =} atan2rev2 (@var{A}, @var{C})
 ## 
-## Compute the reverse atan2 function with
-## @code{atan2 (@var{A}, @var{X}) = @var{C}}.
+## Compute the reverse atan2 function for the second parameter.
+##
+## That is, an enclosure of all @code{x ∈ @var{X}} where
+## @code{atan2 (a, x) ∈ @var{C}} for any @code{a ∈ @var{A}}.
 ##
 ## Accuracy: The result is a valid enclosure.
 ##
+## @comment DO NOT SYNCHRONIZE DOCUMENTATION STRING
+## No one way of decorating this operations gives useful information in all
+## contexts.  Therefore, the result will carry a @code{trv} decoration at best.
+##
 ## @example
 ## @group
 ## atan2rev2 (infsupdec (1, 2), infsupdec ("pi") / 4)
@@ -73,4 +79,7 @@ result = atan2rev2 (intervalpart (a), intervalpart (c), intervalpart (x));
 ## inverse atan2 is not a point function
 result = infsupdec (result, "trv");
 
-endfunction
\ No newline at end of file
+endfunction
+
+%!test "from the documentation string";
+%! assert (isequal (atan2rev2 (infsupdec (1, 2), infsupdec ("pi") / 4), infsupdec ("[0x1.FFFFFFFFFFFFEp-1, 0x1.0000000000001p1]_trv")));
