@@ -171,11 +171,22 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('atan', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('atan2', @var{R}, @var{Y}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('atanh', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('cbrt', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('cos', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('cosh', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('cot', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('coth', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('csc', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('csch', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('dilog', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('ei', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('erf', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('erfc', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('exp', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('expm1', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('fma', @var{R}, @var{X}, @var{Y}, @var{Z})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('gamma', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('gammaln', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('hypot', @var{R}, @var{X}, @var{Y})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('log', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('log2', @var{R}, @var{X})\n"
@@ -187,13 +198,17 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('pow', @var{R}, @var{X}, @var{Y})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('pow2', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('pow10', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('psi', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('rdivide', @var{R}, @var{X}, @var{Y})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('realsqrt', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('rsqrt', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sec', @var{R}, @var{X})\n"
+  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sech', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('sin', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('sinh', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('sinh', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('sinh', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('sqr', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sqrt', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('tan', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('tanh', @var{R}, @var{X})\n"
   "@deftypefnx {Loadable Function} {} mpfr_function_d ('times', @var{R}, @var{X}, @var{Y})\n"
@@ -273,14 +288,36 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
           evaluate (arg1, rnd, &mpfr_atan);
         else if (function == "atanh")
           evaluate (arg1, rnd, &mpfr_atanh);
+        else if (function == "cbrt")
+          evaluate (arg1, rnd, &mpfr_cbrt);
         else if (function == "cos")
           evaluate (arg1, rnd, &mpfr_cos);
         else if (function == "cosh")
           evaluate (arg1, rnd, &mpfr_cosh);
+        else if (function == "cot")
+          evaluate (arg1, rnd, &mpfr_cot);
+        else if (function == "coth")
+          evaluate (arg1, rnd, &mpfr_coth);
+        else if (function == "csc")
+          evaluate (arg1, rnd, &mpfr_csc);
+        else if (function == "csch")
+          evaluate (arg1, rnd, &mpfr_csch);
+        else if (function == "dilog")
+          evaluate (arg1, rnd, &mpfr_li2);
+        else if (function == "ei")
+          evaluate (arg1, rnd, &mpfr_eint);
+        else if (function == "erf")
+          evaluate (arg1, rnd, &mpfr_erf);
+        else if (function == "erfc")
+          evaluate (arg1, rnd, &mpfr_erfc);
         else if (function == "exp")
           evaluate (arg1, rnd, &mpfr_exp);
         else if (function == "expm1")
           evaluate (arg1, rnd, &mpfr_expm1);
+        else if (function == "gamma")
+          evaluate (arg1, rnd, &mpfr_gamma);
+        else if (function == "gammaln")
+          evaluate (arg1, rnd, &mpfr_lngamma);
         else if (function == "log")
           evaluate (arg1, rnd, &mpfr_log);
         else if (function == "log2")
@@ -293,14 +330,22 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
           evaluate (arg1, rnd, &mpfr_exp2);
         else if (function == "pow10")
           evaluate (arg1, rnd, &mpfr_exp10);
+        else if (function == "psi")
+          evaluate (arg1, rnd, &mpfr_digamma);
+        else if (function == "realsqrt")
+          evaluate (arg1, rnd, &mpfr_sqrt);
+        else if (function == "rsqrt")
+          evaluate (arg1, rnd, &mpfr_rec_sqrt);
+        else if (function == "sec")
+          evaluate (arg1, rnd, &mpfr_sec);
+        else if (function == "sech")
+          evaluate (arg1, rnd, &mpfr_sech);
         else if (function == "sin")
           evaluate (arg1, rnd, &mpfr_sin);
         else if (function == "sinh")
           evaluate (arg1, rnd, &mpfr_sinh);
         else if (function == "sqr")
           evaluate (arg1, rnd, &mpfr_sqr);
-        else if (function == "sqrt")
-          evaluate (arg1, rnd, &mpfr_sqrt);
         else if (function == "tan")
           evaluate (arg1, rnd, &mpfr_tan);
         else if (function == "tanh")
